require "soft_deletable/version"

module SoftDeletable
  extend ActiveSupport::Concern

  included do
    # Scopes for soft delete.
    #
    # default: don't include soft deleted records
    # deleted: only soft deleted records
    # with_deleted: all records regardless of soft deletion
    default_scope { where(deleted_at: nil) }
    scope :deleted, -> { with_deleted.where('deleted_at IS NOT NULL') }
    scope :with_deleted, -> { self.unscoped }
  end

  # Soft delete the record
  #
  # Endpoints with a deleted_at value will not appear in the default scope.
  def destroy
    update_attribute(:deleted_at,Time.now)
  end

end